@@ -112,7 +112,7 @@ bool Entity::hasAttr(const std::string& attr) const
     return m_attrs.count(attr) > 0;
 }
 
-SigC::Connection Entity::observe(const std::string& attr, const AttrChangedSlot& slot)
+sigc::connection Entity::observe(const std::string& attr, const AttrChangedSlot& slot)
 {
     // sometimes, I realize how great SigC++ is
     return m_observers[attr].connect(slot);
@@ -328,7 +328,7 @@ void Entity::setAttr(const std::string &attr, const Element &val)
     // fire observers
     
     ObserverMap::const_iterator obs = m_observers.find(attr);
-    if (obs != m_observers.end()) obs->second.emit(attr, target);
+    if (obs != m_observers.end()) obs->second.emit(target);
 
     addToUpdate(attr);
     endUpdate();
