@@ -19,13 +19,12 @@ void ResponseTracker::await(int serialno, ResponseBase* resp)
 
 bool ResponseTracker::handleOp(const RootOperation& op)
 {
-    if (op->getRefno() == 0) return false; // invalid refno, not a response op
+    if (op->isDefaultRefno()) return false; // invalid refno, not a response op
     
     RefnoResponseMap::iterator it = m_pending.find(op->getRefno());
     if (it == m_pending.end()) {
         warning() << "received op with valid refno (" << op->getRefno() << 
             ") but no response is registered";
-        debug() << "op=\n" << op;
         return false;
     }
 
@@ -45,4 +44,13 @@ bool NullResponse::responseReceived(const Atlas::Objects::Operation::RootOperati
     return false;
 }
 
+void* clearMemberResponse(void* d)
+{
+    debug() << "clearing out member response object";
+    
+    void** objectPointer = (void**) d;
+    *objectPointer = NULL;
+    return NULL;
+}
+
 } // of namespace
